@@ -17,7 +17,9 @@ def module_exists(module_name):
         return True
 
 default_config = {
-    'journal': os.path.expanduser("~/journal.txt"),
+    'journals': {
+        "default": os.path.expanduser("~/journal.txt")
+    },
     'editor': "",
     'encrypt': False,
     'password': "",
@@ -26,9 +28,28 @@ default_config = {
     'timeformat': "%Y-%m-%d %H:%M",
     'tagsymbols': '@',
     'highlight': True,
+    'linewrap': 80,
 }
 
 
+def update_config(config, config_path=os.path.expanduser("~/.jrnl_conf")):
+    """Checks if there are keys missing in a given config dict, and if so, updates the config file accordingly.
+    This essentially automatically ports jrnl installations if new config parameters are  introduced in later
+    versions."""
+    missing_keys = set(default_config).difference(config)
+    if missing_keys:
+        for key in missing_keys:
+            config[key] = default_config[key]
+        with open(config_path, 'w') as f:
+            json.dump(config, f, indent=2)
+        print("[.jrnl_conf updated to newest version]")
+
+
+def save_config(config=default_config, config_path=os.path.expanduser("~/.jrnl_conf")):
+    with open(config_path, 'w') as f:
+        json.dump(config, f, indent=2)
+
+
 def install_jrnl(config_path='~/.jrnl_config'):
     def autocomplete(text, state):
         expansions = glob.glob(os.path.expanduser(text)+'*')
@@ -42,7 +63,7 @@ def install_jrnl(config_path='~/.jrnl_config'):
     # Where to create the journal?
     path_query = 'Path to your journal file (leave blank for ~/journal.txt): '
     journal_path = raw_input(path_query).strip() or os.path.expanduser('~/journal.txt')
-    default_config['journal'] = os.path.expanduser(journal_path)
+    default_config['journals']['default'] = os.path.expanduser(journal_path)
 
     # Encrypt it?
     if module_exists("Crypto"):
@@ -60,7 +81,7 @@ def install_jrnl(config_path='~/.jrnl_config'):
         print("clint not found. To turn on highlighting, install clint and set highlight to true in your .jrnl_conf.")
         default_config['highlight'] = False
 
-    open(default_config['journal'], 'a').close() # Touch to make sure it's there
+    open(default_config['journals']['default'], 'a').close() # Touch to make sure it's there
 
     # Write config to ~/.jrnl_conf
     with open(config_path, 'w') as f:
